package com.s5gi.giGuns.guns;

import com.s5gi.giGuns.giGuns;
import org.bukkit.Material;
import org.bukkit.NamespacedKey;
import org.bukkit.inventory.ItemStack;
import org.bukkit.inventory.ShapedRecipe;
import org.bukkit.inventory.meta.ItemMeta;
import org.bukkit.inventory.meta.components.CustomModelDataComponent;

import java.util.List;

public enum BulletType {
    // Penetration in blocks/entities a bullet can travel through before it stops
    PISTOL("&cPistol", BulletType.Recipes.pistol()),
    RIFLE("&eRifle", BulletType.Recipes.rifle()),
    HEAVY("&6Heavy", BulletType.Recipes.heavy()),
    ANTI_TANK("&9Anti-Tank", BulletType.Recipes.antiTank()),;

    private final String prettyName;
    private final ShapedRecipe recipe;
    BulletType(String prettyName, ShapedRecipe recipe) {
        this.prettyName = prettyName;
        this.recipe = recipe;
    }

    public String prettyName() {
        return prettyName;
    }
    public ShapedRecipe recipe() {
        return recipe;
    }

    public ItemStack getItem() {
        return recipe.getResult();
    }

    public static void init() {
        for (BulletType bulletType : BulletType.values()) {
            giGuns.plugin.getServer().addRecipe(bulletType.recipe());
        }
    }

    public static class Recipes {
        public static ItemStack makeAmmo(String prettyName, int textureID) {
            ItemStack gunItem = new ItemStack(Material.BLACK_DYE);
            ItemMeta meta = gunItem.getItemMeta();
            meta.setItemName(giGuns.color(prettyName + " Ammo"));
            CustomModelDataComponent component = meta.getCustomModelDataComponent();
            component.setStrings(List.of("ammomodel" + textureID));
            meta.setCustomModelDataComponent(component);
            gunItem.setItemMeta(meta);
            return gunItem;
        }

        public static ShapedRecipe pistol() {
            ShapedRecipe recipe = new ShapedRecipe(NamespacedKey.fromString("giguns:pistol_ammo"), makeAmmo("&cPistol", 0));
            recipe.shape(" c ", "ngn", "nnn");
            recipe.setIngredient('c', Material.COPPER_INGOT);
            recipe.setIngredient('n', Material.IRON_NUGGET);
            recipe.setIngredient('g', Material.GUNPOWDER);
            return recipe;
        }
        public static ShapedRecipe rifle() {
            ShapedRecipe recipe = new ShapedRecipe(NamespacedKey.fromString("giguns:rifle_ammo"), makeAmmo("&eRifle", 1));
            recipe.shape(" c ", "ngn", "nIn");
            recipe.setIngredient('c', Material.COPPER_INGOT);
            recipe.setIngredient('n', Material.IRON_NUGGET);
            recipe.setIngredient('g', Material.GUNPOWDER);
            recipe.setIngredient('I', Material.IRON_INGOT);
            return recipe;
        }
        public static ShapedRecipe heavy() {
            ShapedRecipe recipe = new ShapedRecipe(NamespacedKey.fromString("giguns:heavy_ammo"), makeAmmo("&6Heavy", 2));
            recipe.shape(" c ", "IgI", "InI");
            recipe.setIngredient('c', Material.COPPER_INGOT);
            recipe.setIngredient('n', Material.IRON_NUGGET);
            recipe.setIngredient('g', Material.GUNPOWDER);
            recipe.setIngredient('I', Material.IRON_INGOT);
            return recipe;
        }
        public static ShapedRecipe antiTank() {
            ShapedRecipe recipe = new ShapedRecipe(NamespacedKey.fromString("giguns:antitank_ammo"), makeAmmo("&9Anti-Tank", 3));
            recipe.shape(" B ", "ITI", "III");
            recipe.setIngredient('T', Material.TNT);
            recipe.setIngredient('I', Material.IRON_INGOT);
            recipe.setIngredient('B', Material.IRON_BLOCK);
            return recipe;
        }
    }
}
